# ncgmp09_definition.py
# module with definitions for NCGMP09 geodatabase schema for 
# ArcGIS 9.3 geodatabases (personal or file) for 
# geologic map data
#  
#  Ralph Haugerud, 10 May 2009 
# 


defaultLength = 255
mapUnitLength = 10
IDLength = 50
memoLength = 3000

# attributes are in order Name DataType NullStatus suggestedLength
# _ID is missing, as it is added programatically, below
startDict = {'DescriptionOfMapUnits':  [['MapUnit','String','NullsOK',mapUnitLength],  
						   ['Label','String','NullsOK',30],
						   ['Name','String','NullsOK',defaultLength],
						   ['FullName','String','NullsOK',defaultLength],
						   ['Age','String','NullsOK',defaultLength],
						   ['Description','String','NullsOK',memoLength],
                                       ['HierarchyKey','String','NoNulls',defaultLength],
						   ['ParagraphStyle','String','NoNulls',defaultLength],
                                       ['AreaFillRGB','String','NullsOK',defaultLength],
                                       ['AreaFillPatternDescription','String','NullsOK',defaultLength],
						   ['DefinitionSourceID','String','NoNulls',IDLength]],
 		   'DataSources':         [['Source','String','NoNulls',500],
						   ['Notes','String','NullsOK',300]],
               'ExtendedAttributes':  [['OwnerTable','String','NoNulls',defaultLength],
						   ['OwnerID','String','NoNulls',IDLength],
						   ['Property','String','NoNulls',defaultLength],
						   ['PropertyValue','String','NullsOK',defaultLength],
						   ['ValueLink','String','NullsOK',IDLength],
						   ['Qualifier','String','NullsOK',defaultLength],
					         ['Notes','String','NullsOK',defaultLength]],
               'GeologicEvents':      [['Event','String','NoNulls',defaultLength],
						   ['AgeDisplay','String','NoNulls',defaultLength],
						   ['AgeYoungerTerm','String','NullsOK',defaultLength],
						   ['AgeOlderTerm','String','NullsOK',defaultLength],
						   ['TimeScale','String','NullsOK',defaultLength],
						   ['AgeYoungerValue','Single','NullsOK'],
						   ['AgeOlderValue','Single','NullsOK'],
						   ['Notes','String','NullsOK',defaultLength],
						   ['DataSourceID','String','NoNulls',IDLength]],
               'Glossary':            [['Term','String','NoNulls',defaultLength],
						   ['Definition','String','NoNulls',memoLength],
						   ['DefinitionSourceID','String','NoNulls',IDLength]],
               'StandardLithology':   [['MapUnit','String','NoNulls',mapUnitLength],
						   ['Lithology','String','NoNulls',defaultLength],
						   ['PartType','String','NoNulls',defaultLength],
						   ['ProportionValue','Single','NullsOK'],
						   ['ProportionTerm','String','NullsOK',defaultLength],
						   ['ScientificConfidence','String','NoNulls',defaultLength],
						   ['DataSourceID','String','NoNulls',IDLength]],
		   'ChangeLog':		  [['OwnerTable','String','NoNulls',defaultLength],
						   ['OwnerID','String','NoNulls',IDLength],
						   ['ChangedWhen','Date','NoNulls'],
						   ['ChangedBy','String','NoNulls',defaultLength],
						   ['OldValue','String','NullsOK',memoLength],
						   ['NewValue','String','NoNulls',memoLength],
						   ['Notes','String','NullsOK',defaultLength]],
               'CMULines':            [['Type','String','NoNulls',defaultLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'ContactsAndFaults':   [['Type','String','NoNulls',defaultLength],
						   ['ExistenceConfidence','String','NoNulls',IDLength],
                                       ['IdentityConfidence','String','NoNulls',IDLength],
                                       ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationMethod','String','NoNulls',defaultLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
                                       ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'ConcealedContactsAndFaults':[['Type','String','NoNulls',defaultLength],
						   ['ExistenceConfidence','String','NoNulls',IDLength],
                                       ['IdentityConfidence','String','NoNulls',IDLength],
                                       ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationMethod','String','NoNulls',defaultLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
                                       ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'OtherLines':          [['Type','String','NoNulls',defaultLength],
						   ['ExistenceConfidence','String','NoNulls',IDLength],
                                       ['IdentityConfidence','String','NoNulls',IDLength],
                                       ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationMethod','String','NoNulls',defaultLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
                                       ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
               'MapUnitPolys':        [['MapUnit','String','NoNulls',mapUnitLength],
						   ['IdentityConfidence','String','NoNulls',IDLength],
						   ['Label','String','NullsOK',IDLength],
						   ['AreaSymbol','String','NullsOK',defaultLength],
						   ['Notes','String','NullsOK',defaultLength],
						   ['DataSourceID','String','NoNulls',IDLength]],
               'OverlayPolys':        [['MapUnit','String','NoNulls',mapUnitLength],
						   ['IdentityConfidence','String','NoNulls',IDLength],
						   ['Label','String','NullsOK',IDLength],
						   ['AreaSymbol','String','NullsOK',defaultLength],
						   ['Notes','String','NullsOK',defaultLength],
						   ['DataSourceID','String','NoNulls',IDLength]],
               'CMUPolys':            [['MapUnit','String','NoNulls',mapUnitLength],
						   ['Label','String','NullsOK',IDLength],
						   ['AreaSymbol','String','NullsOK',defaultLength],
						   ['Notes','String','NullsOK',defaultLength]],
               'CMUPoints':           [['Type','String','NoNulls',defaultLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'Stations':            [['FieldID','String','NoNulls',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationMethod','String','NullsOK',defaultLength],
						   ['TimeDate','Date','NullsOK'],
						   ['Observer','String','NullsOK',defaultLength],
						   ['OutcropDiameterMeters','Single','NullsOK'],
					         ['GPSCoordinates','String','NullsOK',defaultLength],
						   ['PDOP','Single','NullsOK'],
						   ['MapCoordinates','String','NullsOK',defaultLength],
						   ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'GenericPoints':       [['Type','String','NoNulls',defaultLength],
						   ['StationID','String','NullsOK',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationSourceID','String','NoNulls',IDLength],
						   ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'GenericSamples':	  [['Type','String','NoNulls',defaultLength],
						   ['StationID','String','NullsOK',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['FieldSampleID','String','NullsOK',defaultLength],
						   ['AlternateSampleID','String','NullsOK',defaultLength],
						   ['MaterialAnalyzed','String','NullsOK',defaultLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['LocationSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'OrientationPoints':   [['Type','String','NoNulls',defaultLength],
						   ['StationID','String','NullsOK',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['Azimuth','Single','NoNulls'],
						   ['Inclination','Single','NoNulls'],
						   ['IdentityConfidence','String','NoNulls',50],
						   ['OrientationConfidenceDegrees','Single','NoNulls'],
						   ['LocationSourceID','String','NoNulls',IDLength],
						   ['DataSourceID','String','NoNulls',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'GeochronPoints':	  [['Type','String','NoNulls',defaultLength],
						   ['StationID','String','NullsOK',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['FieldSampleID','String','NullsOK',defaultLength],
						   ['AlternateSampleID','String','NullsOK',defaultLength],
						   ['MaterialAnalyzed','String','NullsOK',defaultLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['Age','Single','NoNulls'],
						   ['AgePlusError','Single','NullsOK'],
					         ['AgeMinusError','Single','NullsOK'],
						   ['AgeUnits','String','NoNulls',IDLength],
						   ['LocationSourceID','String','NoNulls',IDLength],
						   ['AnalysisSourceID','String','NullsOK',IDLength],
						   ['Notes','String','NullsOK',defaultLength]],
		   'FossilPoints':	  [['Type','String','NoNulls',defaultLength],
						   ['StationID','String','NullsOK',IDLength],
						   ['MapUnit','String','NoNulls',mapUnitLength],
						   ['FgdcSymbol','String','NullsOK',defaultLength],
						   ['Label','String','NullsOK',IDLength],
						   ['FieldSampleID','String','NullsOK',defaultLength],
						   ['AlternateSampleID','String','NullsOK',defaultLength],
						   ['MaterialAnalyzed','String','NullsOK',defaultLength],
						   ['PlotAtScale','Single','NoNulls'],
						   ['LocationConfidenceMeters','Single','NoNulls'],
						   ['FossilForms','String','NoNulls',memoLength],
						   ['FossilAge','String','NoNulls',defaultLength],
						   ['LocationSourceID','String','NoNulls',IDLength],
						   ['FossilFormsSourceID','String','NoNulls',IDLength],
						   ['FossilAgeSourceID','String','NullsOK',IDLength],
						   ['Notes','String','NullsOK',defaultLength]] }


tableDict = {}

# build CSA feature class attribute definitions
startDict['CSAMapUnitPolys'] = startDict['MapUnitPolys']
startDict['CSAContactsAndFaults'] = startDict['ContactsAndFaults']
startDict['CSAOrientationPoints'] = startDict['OrientationPoints']

# set feature_ID definitions
for table in startDict.keys():
	oldFields = startDict[table]
	newfields = []
	newfields.append([table+'_ID','String','NoNulls',IDLength])
	for field in oldFields:
		newfields.append(field)
	tableDict[table] = newfields

# build MapUnitPoints feature class attribute definitions
tableDict['MapUnitPoints'] = tableDict['MapUnitPolys']